# frozen_string_literal: true

require 'spec_helper'

module ActivityPub
  class Routes
    RSpec.describe '/inbox', type: :route do
      context 'POST /inbox' do
        context 'when the request has an empty body' do
          it 'returns a 400 response' do
            post '/inbox'
            expect(last_response.status).to eq(400)
          end
        end

        context 'when the body is not valid JSON' do
          it 'returns a 400 response' do
            post '/inbox', 'beepboop'
            expect(last_response.status).to eq(400)
          end
        end

        context 'when body is valid JSON' do
          it 'creates a record and returns a 201 status' do
            post '/inbox', '{}'
            expect(last_response.status).to eq(201)
          end
        end

        it 'runs hooks before and after the request' do
          expect(Hooks).
            to receive(:run).
            ordered.
            with('activity_pub.inbox.before_post', kind_of(Rack::Request))
          expect(Hooks).
            to receive(:run).
            ordered.
            with('activity_pub.inbox.after_post', kind_of(Rack::Response))
          post '/inbox', '{}'
        end
      end
    end
  end
end
